summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/dmsbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/dmsbox.h')
-rw-r--r--kstars/kstars/dmsbox.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kstars/kstars/dmsbox.h b/kstars/kstars/dmsbox.h
index c98bc2c1..81590a4e 100644
--- a/kstars/kstars/dmsbox.h
+++ b/kstars/kstars/dmsbox.h
@@ -42,16 +42,17 @@
class dmsBox : public KLineEdit {
Q_OBJECT
-Q_PROPERTY (bool degType READ degType WRITE setDegType)
+ TQ_OBJECT
+TQ_PROPERTY (bool degType READ degType WRITE setDegType)
public:
/**Constructor for the dmsBox object.
*@param parent pointer to the parent QWidget
*@param ni the name of the object
*@param deg if TRUE use deg/arcmin/arcsec; otherwise
* use hours/min/sec.
*/
- dmsBox(TQWidget *parent, const char *ni=0, bool deg=TRUE);
+ dmsBox(TQWidget *tqparent, const char *ni=0, bool deg=TRUE);
/**Destructor (empty)*/
~dmsBox();
@@ -42,16 +42,17 @@
public:
/**Constructor for the dmsBox object.
- *@param parent pointer to the parent QWidget
+ *@param tqparent pointer to the tqparent TQWidget
*@param ni the name of the object
*@param deg if TRUE use deg/arcmin/arcsec; otherwise